summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/callable.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kross/api/callable.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kross/api/callable.h')
-rw-r--r--lib/kross/api/callable.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/lib/kross/api/callable.h b/lib/kross/api/callable.h
index 4d25bd91..63edb067 100644
--- a/lib/kross/api/callable.h
+++ b/lib/kross/api/callable.h
@@ -24,8 +24,8 @@
#include "list.h"
//#include "exception.h"
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
#include <ksharedptr.h>
namespace Kross { namespace Api {
@@ -51,7 +51,7 @@ namespace Kross { namespace Api {
* \param name The name this callable object has and
* it is reachable as via \a getChild() .
*/
- Callable(const QString& name);
+ Callable(const TQString& name);
/**
* Destructor.
@@ -63,7 +63,7 @@ namespace Kross { namespace Api {
* has a name which is used e.g. on \a addChild to be able
* to identify the object itself.
*/
- const QString getName() const;
+ const TQString getName() const;
/**
* Return the class name. This could be something
@@ -72,14 +72,14 @@ namespace Kross { namespace Api {
*
* \return The name of this class.
*/
- virtual const QString getClassName() const;
+ virtual const TQString getClassName() const;
/**
* Returns if the defined child is avaible.
*
* \return true if child exists else false.
*/
- bool hasChild(const QString& name) const;
+ bool hasChild(const TQString& name) const;
/**
* Return the defined child or NULL if there is
@@ -89,14 +89,14 @@ namespace Kross { namespace Api {
* \return The Object matching to the defined
* name or NULL if there is no such Object.
*/
- Object::Ptr getChild(const QString& name) const;
+ Object::Ptr getChild(const TQString& name) const;
/**
- * Return all children.
+ * Return all tqchildren.
*
* \return A \a ObjectMap of children this Object has.
*/
- QMap<QString, Object::Ptr> getChildren() const;
+ TQMap<TQString, Object::Ptr> getChildren() const;
/**
* Add a new child. Replaces a possible already existing
@@ -107,7 +107,7 @@ namespace Kross { namespace Api {
* \return true if the Object was added successfully
* else false.
*/
- bool addChild(const QString& name, Object* object);
+ bool addChild(const TQString& name, Object* object);
/**
* Same as the \a addChild method above but for callable
@@ -122,23 +122,23 @@ namespace Kross { namespace Api {
* If there doesn't exists an Object with
* such name just nothing will be done.
*/
- void removeChild(const QString& name);
+ void removeChild(const TQString& name);
/**
* Remove all children.
*/
void removeAllChildren();
/**
* Call the object.
*/
- virtual Object::Ptr call(const QString& name, List::Ptr arguments);
+ virtual Object::Ptr call(const TQString& name, List::Ptr arguments);
private:
/// Name this callable object has.
- QString m_name;
+ TQString m_name;
/// A list of childobjects.
- QMap<QString, Object::Ptr> m_children;
+ TQMap<TQString, Object::Ptr> m_tqchildren;
};
}}
@@ -89,14 +89,14 @@ namespace Kross { namespace Api {
*
- * \return A \a ObjectMap of children this Object has.
+ * \return A \a ObjectMap of tqchildren this Object has.
*/
@@ -122,23 +122,23 @@ namespace Kross { namespace Api {
/**
- * Remove all children.
+ * Remove all tqchildren.
*/
void removeAllChildren();